<h1>Classification</h1>
<div class="photon-docu-header">
    <p>
        Classification is one of the central machine learning tasks. With PHOTONAI, classification pipelines can
         be created and designed easily.
    </p>
</div>

<h3>Classification with default pipeline</h3>

``` python
{% include "examples/basic/classification.py" %} 

```

<h3>Classification with custom pipeline</h3>

``` python
{% include "examples/basic/classification_custom.py" %} 

```